@@ -7,7 +7,6 @@ class BucketFsError(Exception):
 
 
 class BucketFsDeprecationWarning(DeprecationWarning):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
 
@@ -16,5 +15,5 @@ warnings.warn(
     "This API is deprecated and will be dropped in the future, "
     "please use the new API in the `exasol.bucketfs` package.",
     BucketFsDeprecationWarning,
-    stacklevel=2
+    stacklevel=2,
 )
