@@ -1,11 +1,13 @@
 import requests
+
 from exasol_bucketfs_utils_python import bucketfs_utils
-from exasol_bucketfs_utils_python.bucketfs_utils import generate_bucket_http_url
 from exasol_bucketfs_utils_python.bucket_config import BucketConfig
+from exasol_bucketfs_utils_python.bucketfs_utils import generate_bucket_http_url
+
 
 def delete_file_in_bucketfs(
-        bucket_config: BucketConfig,
-        bucket_file_path: str = "") -> None:
+    bucket_config: BucketConfig, bucket_file_path: str = ""
+) -> None:
     """
     Delete the file in bucket under a given path in BucketFS
 
